#######################
ReactionTypeCustomEmoji
#######################


.. automodule:: litegram.types.reaction_type_custom_emoji
    :members:
    :member-order: bysource
    :undoc-members: True
    :exclude-members: model_config,model_fields
